/*
 * Copyright (c) 2012-2014 Wind River Systems, Inc.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <zephyr.h>
#include <string.h>
#include <sys/printk.h>
#include <drivers/uart.h>
#include <device.h>

static const struct device *uart;

static uint8_t m_uart_rx_buff[2][256];
static uint8_t *mp_current_rx_buff = m_uart_rx_buff[0];

static void uart_cb(const struct device *dev, struct uart_event *evt, void *user_data)
{
	int err = 0;

	printk("uart_cb evt %d\n", evt->type);

	switch (evt->type) {
	case UART_TX_DONE:
		break;

	case UART_RX_RDY:
		/* Print the data echoed back from the nRF52840 */
		printk("UART received: %s", evt->data.rx.buf);
		break;

	case UART_RX_DISABLED:
		break;

	case UART_RX_BUF_REQUEST:
		/* Provide a new easyDMA buffer for UART RX */
		mp_current_rx_buff = (mp_current_rx_buff == m_uart_rx_buff[0]) ? m_uart_rx_buff[1] :
										       m_uart_rx_buff[0];
		err = uart_rx_buf_rsp(dev, mp_current_rx_buff, sizeof(m_uart_rx_buff[0]));
		if (err) {
			printk("uart_rx_buf_rsp() failed. (err: %d)\n", err);
		}
		break;

	case UART_RX_BUF_RELEASED:
		break;

	case UART_TX_ABORTED:
		break;

	default:
		break;
	}
}

static int uart_init(void)
{
	int err = 0;

	uart = device_get_binding("UART_1");
	if (!uart) {
		return -ENXIO;
	}

	err = uart_callback_set(uart, uart_cb, NULL);
	if (err) {
		return err;
	}

	return uart_rx_enable(uart, mp_current_rx_buff, sizeof(m_uart_rx_buff[0]), 50);
}

void main(void)
{
	int err;

	uint8_t tx_message[] = "loopback test\n\r";
	uint16_t tx_len = sizeof(tx_message);

	err = uart_init();
	if (err) {
		printk("uart_init() failed. (err: %d)\n", err);
	}
	while (true) {
		k_sleep(K_MSEC(3000));
		err = uart_tx(uart, tx_message, tx_len, SYS_FOREVER_MS);
		if (err) {
			printk("uart_tx() failed. (err: %d)\n", err);
		}
	}
}
